import React, { useEffect, useRef } from 'react';
import OlMap from 'ol/Map';
import View from 'ol/View';
import TileLayer from 'ol/layer/Tile';
import Attribution from 'ol/control/Attribution';
import OSM, { ATTRIBUTION } from 'ol/source/OSM';

import './Map.css';
import Collection from 'ol/Collection';

export interface MapProperties {}

export const Map: React.FC<MapProperties> = (props: MapProperties) => {
  const target = useRef<HTMLDivElement>(null);

  useEffect(() => {
    const controls = new Collection([new Attribution({ collapsible: true })]);
    const map = new OlMap({
      view: new View({
        center: [0, 0],
        zoom: 1,
      }),
      layers: [
        new TileLayer({
          source: new OSM(),
        }),
      ],
      target: target.current ?? undefined,
      controls,
    });
  }, []);

  return <div ref={target} className='ol-map' />;
};

export default Map;
